import type { Change } from 'diff';
import type { StyleProp, TextStyle } from 'react-native';
declare type Suggestion = {
    id: string;
    name: string;
};
declare type TriggerData = {
    original: string;
    trigger: string;
    name: string;
    id: string;
};
declare type CharactersDiffChange = Omit<Change, 'count'> & {
    count: number;
};
declare type RegexMatchResult = string[] & {
    0: string;
    1: string;
    2: string;
    3: string;
    4: string;
    index: number;
    groups: TriggerData;
};
declare type Position = {
    start: number;
    end: number;
};
/**
 * Props that we can provide to the suggestions components
 */
declare type SuggestionsProvidedProps = {
    keyword?: string;
    onSelect: (suggestion: Suggestion) => void;
};
declare type TriggerPartType<TriggerName = string> = {
    trigger: string;
    allowedSpacesCount?: number;
    isInsertSpaceAfterMention?: boolean;
    textStyle?: StyleProp<TextStyle>;
    getPlainString?: (mention: TriggerData) => string;
};
declare type PatternPartType = {
    pattern: RegExp;
    textStyle?: StyleProp<TextStyle>;
};
declare type PartType = TriggerPartType | PatternPartType;
/**
 * Config of trigger part types
 */
declare type TriggersConfig<TriggerName extends string> = Record<TriggerName, TriggerPartType<TriggerName>>;
/**
 * Config of pattern part types that can highlight some matches in the `TextInput`
 */
declare type PatternsConfig = Record<string, PatternPartType>;
declare type Part = {
    text: string;
    position: Position;
    partType?: PartType;
    data?: TriggerData;
};
declare type MentionState = {
    plainText: string;
    parts: Part[];
};
declare type Triggers<TriggerName extends string> = Record<TriggerName, SuggestionsProvidedProps>;
declare type UseMentionsConfig<TriggerName extends string> = {
    value: string;
    onChange: (value: string) => void;
    triggersConfig?: TriggersConfig<TriggerName>;
    patternsConfig?: PatternsConfig;
    onSelectionChange?: (selection: Position) => void;
};
export type { Suggestion, TriggerData, CharactersDiffChange, RegexMatchResult, Position, Part, SuggestionsProvidedProps, TriggerPartType, PatternPartType, TriggersConfig, PatternsConfig, PartType, MentionState, Triggers, UseMentionsConfig, };
